pub struct Args {
pub op: OpName,
pub log_type: LogType,
pub paths: Vec<PathBuf>,
}Fields
op: OpNameop is the set operation requested
log_type: LogTypeShould we count the number of times each line occurs?
paths: Vec<PathBuf>paths is the list of files from the command line